@@ -1,26 +1,8 @@
 """
 Building Blocks of a Dynamic Visualization - :mod:`bpsci.core`
-==============================================
+==============================================================
 The bpsci core is a collection of classes and methods used to create dynamic visualizations.
 
-Building Blocks (Classes)
-------------
-All data is provided through the following data objects:
-    .. autosummary::
-       :nosignatures:
-       init_anim
-       ref_frame
-       dyn_obj
-       dyn_vec
-       anim_text
-
-To initialize any animation, call the :class:`init_anim` object to setup the global parameters of the simulation.
-
-Then call the :class:`dyn_obj` object to create an :mod:'bpsci' object that is capable of animation; this is the basic building block for any moving object. 
-
-
-API Reference
--------------
 """
 
 import numpy as np
